| Title: | Longitudinal Wages Data from the National Longitudinal Survey of Youth 1979 |
|---|---|
| Description: | Longitudinal wages datasets and several demographic variables from the National Longitudinal Survey of Youth from 1979 to 2018. There are three data sets in this package: The wages data from the NLSY79 cohort; The wages data of the high school dropouts and; The demographic data of NLSY79 cohort. |
| Authors: | Dewi Amaliah [aut, cre], Di Cook [aut], Emi Tanaka [aut], Kate Hyde [ctb], Nicholas Tierney [ctb] |
| Maintainer: | Dewi Amaliah <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.1 |
| Built: | 2026-07-05 08:34:39 UTC |
| Source: | https://github.com/numbats/yowie |
This function aims to adjust the wage column in wages and wages_hs_do with the
inflation rate of the base year of your choice.
The inflation rate is calculated from the CPI data published by the US Bureau of Labor Statistics (BLS).
This function needs internet connection to download the data from the BLS website.
The code is adapted from Kris Eberwein in R Bloggers website. https://www.r-bloggers.com/2015/12/calculate-inflation-with-r/
adj_inflation(base_year)adj_inflation(base_year)
base_year |
The base year of your choice (4 digits-year without quotation mark). |
wages and wages_hs_do data with a new column of inflation-adjusted wages value.
## Not run: inflation_adjust(1990) ## End(Not run)## Not run: inflation_adjust(1990) ## End(Not run)
A data set contains demographic information of the NLSY79 cohort. The cohort included 12,686 respondents ages 14-22 when first interviewed in 1979.
A data frame contains 12,686 rows and 8 variables:
A unique individual's ID number.
The age of the subject in 1979.
Sex of the subject: f = Female and m = Male.
Race of the subject: NBH = Non-Black,Non-Hispanic; H = Hispanic; B = Black.
Highest grade completed.
Integer of highest grade completed.
The highest grade completed in 1979 (integer value).
Wether the respondent had a high school diploma or Graduate Equivalency Degree (GED). 1: High school diploma; 2: GED; 3: Both
The U.S. Bureau of Labor Statistics. (2021, January 6). National Longitudinal Survey of Youth 1979. https://www.nlsinfo.org/content/cohorts/nlsy79/get-data
A data set contains longitudinal data of mean hourly wages along with several demographic variables of Americans from the National Longitudinal Survey of Youth (NLSY79) held by the U.S. Bureau of Labor Statistics from Round 1 (1979 survey year) to Round 28 (2018 survey year). The cohort provided in this data set of the NLSY79 cohort who participated in at least 3 survey rounds.
A tsibble with 206,795 rows and 18 variables:
A unique individual's ID number. This is the key of the data.
The year the observation was taken. This could be the index of the data.
The mean of the hourly wages the individual gets at each of their different jobs. The value could be a weighted or an arithmetic mean. The weighted mean is used when the information of hours of work as the weight is available. The mean hourly wage could also be a predicted value if the original value is considered influential by the robust linear regression as part of data cleaning.
The age of the subject in 1979.
Sex of the subject: f = Female and m = Male.
Race of the subject: NBH = Non-Black,Non-Hispanic; H = Hispanic; B = Black.
Integer value of the highest grade completed corresponding to year.
Highest grade completed.
Integer of highest grade completed.
The highest grade completed in 1979 (integer value).
Wether the respondent had a high school diploma or Graduate Equivalency Degree (GED). 1: High school diploma; 2: GED; 3: Both
Number of jobs that an individual has.
The total number of hours the individual usually works per week.
The year when the individual starting to work.
The length of time in the workforce in years (year - stwork).
Work experience, i.e., the number of years worked
Whether the mean hourly wage is weighted mean, using the hour work as the weight, or regular/arithmetic mean. TRUE = is weighted mean. FALSE = is regular mean.
Whether the mean hourly wage is a predicted value or not.
The U.S. Bureau of Labor Statistics. (2021, January 6). National Longitudinal Survey of Youth 1979. https://www.nlsinfo.org/content/cohorts/nlsy79/get-data
# data summary wages library(ggplot2) library(dplyr) library(tsibble) wages_ids <- key_data(wages) %>% select(id) wages %>% dplyr::filter(id %in% sample_n(wages_ids, 10)$id) %>% ggplot() + geom_line(aes(x = year, y = wage, group = id), alpha = 0.8)# data summary wages library(ggplot2) library(dplyr) library(tsibble) wages_ids <- key_data(wages) %>% select(id) wages %>% dplyr::filter(id %in% sample_n(wages_ids, 10)$id) %>% ggplot() + geom_line(aes(x = year, y = wage, group = id), alpha = 0.8)
A data set contains longitudinal data of mean hourly wages along with several demographic variables from the National Longitudinal Survey of Youth (NLSY79) held by the U.S. Bureau of Labor Statistics from Round 1 (1979 survey year) to Round 28 (2018 survey year). The cohort provided in this data set is high school dropouts in NLSY79 cohort and participated in at least 3 survey rounds.
A tsibble contains 14,174 rows and 18 variables:
#'
A unique individual's ID number. This is the key of the data.
The year the observation was taken. This could be the index of the data.
The mean of the hourly wages the individual gets at each of their different jobs. The value could be a weighted or an arithmetic mean. The weighted mean is used when the information of hours of work as the weight is available. The mean hourly wage could also be a predicted value if the original value is considered influential by the robust linear regression as part of data cleaning.
The age of the subject in 1979.
Sex of the subject: f = Female and m = Male.
Race of the subject: NBH = Non-Black,Non-Hispanic; H = Hispanic; B = Black.
Integer value of the highest grade completed corresponding to year.
Highest grade completed.
Integer of highest grade completed.
The highest grade completed in 1979 (integer value).
Wether the respondent had a high school diploma or Graduate Equivalency Degree (GED). 1: High school diploma; 2: GED; 3: Both
Number of jobs that an individual has.
The total number of hours the individual usually works per week.
The year when the individual starting to work.
The length of time in the workforce in years (year - stwork).
Work experience, i.e., the number of years worked
Whether the mean hourly wage is weighted mean, using the hour work as the weight, or regular/arithmetic mean. TRUE = is weighted mean. FALSE = is regular mean.
Whether the mean hourly wage is a predicted value or not.
The U.S. Bureau of Labor Statistics. (2021, January 6). National Longitudinal Survey of Youth 1979. https://www.nlsinfo.org/content/cohorts/nlsy79/get-data
# saving the data into a new object library(yowie) library(tsibble) wages_hs_do %>% key_data()# saving the data into a new object library(yowie) library(tsibble) wages_hs_do %>% key_data()